diff mbox series

[ovs-dev] ci: Set platform parameter when building DPDK.

Message ID 20240507150434.2364618-1-david.marchand@redhat.com
State Accepted
Commit 5dfbc643f3687ce6b5b80f67481eaaead3ec53a2
Delegated to: Simon Horman
Headers show
Series [ovs-dev] ci: Set platform parameter when building DPDK. | expand

Checks

Context Check Description
ovsrobot/apply-robot success apply and check: success
ovsrobot/github-robot-_Build_and_Test success github build: passed
ovsrobot/intel-ovs-compilation success test: success

Commit Message

David Marchand May 7, 2024, 3:04 p.m. UTC
This change has no impact, since -Dmachine=default gets converted by
DPDK into -Dplatform=generic (since v21.08, see the link to DPDK commit
below). Yet, switch to explicitly setting -Dplatform and avoid the
following warning:

2024-04-18T14:50:16.8001092Z config/meson.build:113: WARNING: The
	"machine" option is deprecated. Please use "cpu_instruction_set"
	instead.

While at it, solve another warning and call explicitly meson setup.

2024-04-18T14:50:17.0770596Z WARNING: Running the setup command as
	`meson [options]` instead of `meson setup [options]` is ambiguous
	and deprecated.

Link: https://git.dpdk.org/dpdk/commit/?id=bf66003b51ec
Signed-off-by: David Marchand <david.marchand@redhat.com>
---
 .ci/dpdk-build.sh | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

Comments

Simon Horman May 7, 2024, 4:29 p.m. UTC | #1
On Tue, May 07, 2024 at 05:04:34PM +0200, David Marchand wrote:
> This change has no impact, since -Dmachine=default gets converted by
> DPDK into -Dplatform=generic (since v21.08, see the link to DPDK commit
> below). Yet, switch to explicitly setting -Dplatform and avoid the
> following warning:
> 
> 2024-04-18T14:50:16.8001092Z config/meson.build:113: WARNING: The
> 	"machine" option is deprecated. Please use "cpu_instruction_set"
> 	instead.
> 
> While at it, solve another warning and call explicitly meson setup.
> 
> 2024-04-18T14:50:17.0770596Z WARNING: Running the setup command as
> 	`meson [options]` instead of `meson setup [options]` is ambiguous
> 	and deprecated.
> 
> Link: https://git.dpdk.org/dpdk/commit/?id=bf66003b51ec
> Signed-off-by: David Marchand <david.marchand@redhat.com>

Acked-by: Simon Horman <horms@ovn.org>
Eelco Chaudron May 8, 2024, 8:52 a.m. UTC | #2
On 7 May 2024, at 17:04, David Marchand wrote:

> This change has no impact, since -Dmachine=default gets converted by
> DPDK into -Dplatform=generic (since v21.08, see the link to DPDK commit
> below). Yet, switch to explicitly setting -Dplatform and avoid the
> following warning:
>
> 2024-04-18T14:50:16.8001092Z config/meson.build:113: WARNING: The
> 	"machine" option is deprecated. Please use "cpu_instruction_set"
> 	instead.
>
> While at it, solve another warning and call explicitly meson setup.
>
> 2024-04-18T14:50:17.0770596Z WARNING: Running the setup command as
> 	`meson [options]` instead of `meson setup [options]` is ambiguous
> 	and deprecated.
>
> Link: https://git.dpdk.org/dpdk/commit/?id=bf66003b51ec
> Signed-off-by: David Marchand <david.marchand@redhat.com>

Thanks, the change looks good to me.

Acked-by: Eelco Chaudron <echaudro@redhat.com>
Simon Horman May 9, 2024, 12:34 p.m. UTC | #3
On Tue, May 07, 2024 at 05:04:34PM +0200, David Marchand wrote:
> This change has no impact, since -Dmachine=default gets converted by
> DPDK into -Dplatform=generic (since v21.08, see the link to DPDK commit
> below). Yet, switch to explicitly setting -Dplatform and avoid the
> following warning:
> 
> 2024-04-18T14:50:16.8001092Z config/meson.build:113: WARNING: The
> 	"machine" option is deprecated. Please use "cpu_instruction_set"
> 	instead.
> 
> While at it, solve another warning and call explicitly meson setup.
> 
> 2024-04-18T14:50:17.0770596Z WARNING: Running the setup command as
> 	`meson [options]` instead of `meson setup [options]` is ambiguous
> 	and deprecated.
> 
> Link: https://git.dpdk.org/dpdk/commit/?id=bf66003b51ec
> Signed-off-by: David Marchand <david.marchand@redhat.com>

Thanks David and Eelco,

Applied to main

- ci: Set platform parameter when building DPDK.
  https://github.com/openvswitch/ovs/commit/5dfbc643f368
diff mbox series

Patch

diff --git a/.ci/dpdk-build.sh b/.ci/dpdk-build.sh
index 23f3166a54..e1b8e3ccbb 100755
--- a/.ci/dpdk-build.sh
+++ b/.ci/dpdk-build.sh
@@ -25,9 +25,9 @@  function build_dpdk()
         pushd dpdk-src
     fi
 
     # Switching to 'default' machine to make the dpdk cache usable on
     # different CPUs. We can't be sure that all CI machines are exactly same.
-    DPDK_OPTS="$DPDK_OPTS -Dmachine=default"
+    DPDK_OPTS="$DPDK_OPTS -Dplatform=generic"
 
     # Disable building DPDK unit tests. Not needed for OVS build or tests.
     DPDK_OPTS="$DPDK_OPTS -Dtests=false"
@@ -49,7 +49,7 @@  function build_dpdk()
     # Install DPDK using prefix.
     DPDK_OPTS="$DPDK_OPTS --prefix=$DPDK_INSTALL_DIR"
 
-    meson $DPDK_OPTS build
+    meson setup $DPDK_OPTS build
     ninja -C build
     ninja -C build install
     popd
@@ -25,9 +25,9 @@  function build_dpdk()
     fi
 
-    # Switching to 'default' machine to make the dpdk cache usable on
+    # Switching to 'generic' platform to make the dpdk cache usable on
     # different CPUs. We can't be sure that all CI machines are exactly same.